@@ -1,14 +1,23 @@
 """Module containing data modles for the Hermes library"""
 
-from typing import Dict
-from pydantic import BaseModel
+from typing import Dict, Optional
+from pydantic import BaseModel, validator, ValidationError
 
 
 class GaugePayload(BaseModel):
     """Dataclass containing values for
     Gauge payload"""
-    value: float
+    operation: str
     labels: Dict[str, str]
+    value: Optional[float]
+
+    @validator('operation')
+    def check_operation(cls, val):
+        """Function used to check that operation type
+        is valid for gauges"""
+        if val in ['increment', 'decrement', 'set']:
+            return val
+        raise ValidationError
 
 class PrometheusGauge(BaseModel):
     """Dataclass containing values for
